# rough-theory: Python igraph for rough set theory :snake:
<a href="https://github.com/johnHostetter/rough-theory/actions"><img alt="Actions Status" src="https://github.com/johnHostetter/rough-theory/workflows/Test/badge.svg"></a>
<a href="https://github.com/johnHostetter/rough-theory/actions"><img alt="Actions Status" src="https://github.com/johnHostetter/rough-theory/workflows/Pylint/badge.svg"></a>
<a href="https://codecov.io/github/johnHostetter/rough-theory" > 
 <img src="https://codecov.io/github/johnHostetter/rough-theory/branch/main/graph/badge.svg?token=N02Z5Q7MX7"/> 
 </a>
<a href="https://github.com/psf/regime"><img alt="Code style: black" src="https://img.shields.io/badge/code%20style-black-000000.svg"></a>

The `rough-theory` library offers various operations to analyze and leverage discernibility of knowledge. It uses minimal dependencies to implement these features and has a graph theory backend (via `igraph`).
